/**
 * @public
 * Checks if a specific API, component, or capability is available in the current environment.
 * @param schema - The schema string to check (e.g., "component.button", "api.request").
 * @returns True if available, false otherwise. Returns false if the underlying command execution fails.
 *
 * @example
 * ```typescript
 * // Check if a basic API is available
 * if (canIUse('api.request')) {
 *   console.log('Request API is available.');
 * } else {
 *   console.log('Request API is not available.');
 * }
 *
 * // Check for a component
 * if (canIUse('component.button')) {
 *   console.log('Button component is supported.');
 * }
 *
 * // Check for a specific method or property on an API
 * // The schema format "ads:showInterstitialAd" is a common pattern for such checks.
 * if (canIUse('ads:showInterstitialAd')) {
 *   console.log('Showing interstitial ads is supported.');
 * }
 * ```
 */
export declare function canIUse(schema: string): boolean;
