import { ResponseType, StandardResponse } from '@jolibox/types';
/**
 * Data structure for successful login.
 * @public
 */
export interface ILoginSuccessData {
    isLogin: boolean;
    token?: string;
}
/**
 * @public
 * Initiates the Jolibox login process.
 * @returns A promise that resolves with the standard response containing login status and token if successful, or an error-like object if platform does not support login.
 */
export declare function login(): Promise<StandardResponse<ILoginSuccessData> | {
    code: ResponseType;
    message: string;
}>;
/**
 * Data structure for successful session check.
 * @public
 */
export interface ICheckSessionSuccessData {
    isLogin: boolean;
}
/**
 * @public
 * Checks the current session status.
 * @returns A promise that resolves with the standard response containing session status if successful, or an error-like object if platform does not support checkSession.
 */
export declare function checkSession(): Promise<StandardResponse<ICheckSessionSuccessData> | {
    code: ResponseType;
    message: string;
}>;
